==> cscec5b-rmat-impl-3.0.1-20240124.105445-281-sources.jar: com/ejianc/business/rmat/vo/ReportCorpLowerVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * 日租金
 *
 * @author generator
 *
 */
public class ReportCorpLowerVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long topId;
    private Long orgId; // 项目组织id
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private BigDecimal dailyMny; // 当日租金
    private BigDecimal yearMny; // 年度租金
    private BigDecimal sumMny; // 累计租金
    private BigDecimal sumPipeNum; // 当前在租量架管
    private BigDecimal sumClampNum; // 当前在租量扣件
    private BigDecimal sumLunkNum; // 当前在租量轮扣
    private BigDecimal pipeRate; // 架管损耗率
    private BigDecimal clampRate; // 扣件损耗率
    private Long realCorpId;      // NC所属组织ID
    private String realNcCorp;    // NC所属组织PK
    private String realCorpName;  // NC所属组织名称

    private BigDecimal sumPipeInNum; // 架管累计进场数量
    private BigDecimal sumPipeOutNum; // 架管累计退场+赔偿数量
    private BigDecimal sumClampInNum; // 扣件累计进场数量
    private BigDecimal sumClampOutNum; // 扣件累计退场+赔偿数量
    private BigDecimal sumLunkInNum; // 轮扣累计进场数量
    private BigDecimal sumLunkOutNum; // 轮扣累计退场+赔偿数量

    public Long getTopId() {
        return topId;
    }

    public void setTopId(Long topId) {
        this.topId = topId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public BigDecimal getDailyMny() {
        return dailyMny;
    }

    public void setDailyMny(BigDecimal dailyMny) {
        this.dailyMny = dailyMny;
    }

    public BigDecimal getYearMny() {
        return yearMny;
    }

    public void setYearMny(BigDecimal yearMny) {
        this.yearMny = yearMny;
    }

    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }

    public BigDecimal getSumPipeNum() {
        return sumPipeNum;
    }

    public void setSumPipeNum(BigDecimal sumPipeNum) {
        this.sumPipeNum = sumPipeNum;
    }

    public BigDecimal getSumClampNum() {
        return sumClampNum;
    }

    public void setSumClampNum(BigDecimal sumClampNum) {
        this.sumClampNum = sumClampNum;
    }

    public BigDecimal getSumLunkNum() {
        return sumLunkNum;
    }

    public void setSumLunkNum(BigDecimal sumLunkNum) {
        this.sumLunkNum = sumLunkNum;
    }

    public BigDecimal getPipeRate() {
        return pipeRate;
    }

    public void setPipeRate(BigDecimal pipeRate) {
        this.pipeRate = pipeRate;
    }

    public BigDecimal getClampRate() {
        return clampRate;
    }

    public void setClampRate(BigDecimal clampRate) {
        this.clampRate = clampRate;
    }

    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }

    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }

    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }

    public BigDecimal getSumPipeInNum() {
        return sumPipeInNum;
    }

    public void setSumPipeInNum(BigDecimal sumPipeInNum) {
        this.sumPipeInNum = sumPipeInNum;
    }

    public BigDecimal getSumPipeOutNum() {
        return sumPipeOutNum;
    }

    public void setSumPipeOutNum(BigDecimal sumPipeOutNum) {
        this.sumPipeOutNum = sumPipeOutNum;
    }

    public BigDecimal getSumClampInNum() {
        return sumClampInNum;
    }

    public void setSumClampInNum(BigDecimal sumClampInNum) {
        this.sumClampInNum = sumClampInNum;
    }

    public BigDecimal getSumClampOutNum() {
        return sumClampOutNum;
    }

    public void setSumClampOutNum(BigDecimal sumClampOutNum) {
        this.sumClampOutNum = sumClampOutNum;
    }

    public BigDecimal getSumLunkInNum() {
        return sumLunkInNum;
    }

    public void setSumLunkInNum(BigDecimal sumLunkInNum) {
        this.sumLunkInNum = sumLunkInNum;
    }

    public BigDecimal getSumLunkOutNum() {
        return sumLunkOutNum;
    }

    public void setSumLunkOutNum(BigDecimal sumLunkOutNum) {
        this.sumLunkOutNum = sumLunkOutNum;
    }
}

==> cscec5b-rmat-impl-3.0.1-20241011.033953-313-sources.jar: com/ejianc/business/rmat/vo/ReportCorpLowerVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * 日租金
 *
 * @author generator
 *
 */
public class ReportCorpLowerVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long topId;
    private Long orgId; // 项目组织id
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private String orgShortName; // 项目组织简称
    private BigDecimal dailyMny; // 当日租金
    private BigDecimal yearMny; // 年度租金
    private BigDecimal sumMny; // 累计租金
    private BigDecimal sumPipeNum; // 当前在租量架管
    private BigDecimal sumClampNum; // 当前在租量扣件
    private BigDecimal sumLunkNum; // 当前在租量轮扣
    private BigDecimal pipeRate; // 架管损耗率
    private BigDecimal clampRate; // 扣件损耗率
    private Long realCorpId;      // NC所属组织ID
    private String realNcCorp;    // NC所属组织PK
    private String realCorpName;  // NC所属组织名称

    private BigDecimal sumPipeInNum; // 架管累计进场数量
    private BigDecimal sumPipeOutNum; // 架管累计退场+赔偿数量
    private BigDecimal sumPipePcNum; // 架管累计赔偿数量
    private BigDecimal sumClampInNum; // 扣件累计进场数量
    private BigDecimal sumClampOutNum; // 扣件累计退场+赔偿数量
    private BigDecimal sumClampPcNum; // 扣件累计赔偿数量
    private BigDecimal sumLunkInNum; // 轮扣累计进场数量
    private BigDecimal sumLunkOutNum; // 轮扣累计退场+赔偿数量
    private BigDecimal sumLunkPcNum; // 轮扣累计赔偿数量

    private BigDecimal scaleZb;//平米指标

    public Long getTopId() {
        return topId;
    }

    public void setTopId(Long topId) {
        this.topId = topId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public BigDecimal getDailyMny() {
        return dailyMny;
    }

    public void setDailyMny(BigDecimal dailyMny) {
        this.dailyMny = dailyMny;
    }

    public BigDecimal getYearMny() {
        return yearMny;
    }

    public void setYearMny(BigDecimal yearMny) {
        this.yearMny = yearMny;
    }

    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }

    public BigDecimal getSumPipeNum() {
        return sumPipeNum;
    }

    public void setSumPipeNum(BigDecimal sumPipeNum) {
        this.sumPipeNum = sumPipeNum;
    }

    public BigDecimal getSumClampNum() {
        return sumClampNum;
    }

    public void setSumClampNum(BigDecimal sumClampNum) {
        this.sumClampNum = sumClampNum;
    }

    public BigDecimal getSumLunkNum() {
        return sumLunkNum;
    }

    public void setSumLunkNum(BigDecimal sumLunkNum) {
        this.sumLunkNum = sumLunkNum;
    }

    public BigDecimal getPipeRate() {
        return pipeRate;
    }

    public void setPipeRate(BigDecimal pipeRate) {
        this.pipeRate = pipeRate;
    }

    public BigDecimal getClampRate() {
        return clampRate;
    }

    public void setClampRate(BigDecimal clampRate) {
        this.clampRate = clampRate;
    }

    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }

    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }

    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }

    public BigDecimal getSumPipeInNum() {
        return sumPipeInNum;
    }

    public void setSumPipeInNum(BigDecimal sumPipeInNum) {
        this.sumPipeInNum = sumPipeInNum;
    }

    public BigDecimal getSumPipeOutNum() {
        return sumPipeOutNum;
    }

    public void setSumPipeOutNum(BigDecimal sumPipeOutNum) {
        this.sumPipeOutNum = sumPipeOutNum;
    }

    public BigDecimal getSumClampInNum() {
        return sumClampInNum;
    }

    public void setSumClampInNum(BigDecimal sumClampInNum) {
        this.sumClampInNum = sumClampInNum;
    }

    public BigDecimal getSumClampOutNum() {
        return sumClampOutNum;
    }

    public void setSumClampOutNum(BigDecimal sumClampOutNum) {
        this.sumClampOutNum = sumClampOutNum;
    }

    public BigDecimal getSumLunkInNum() {
        return sumLunkInNum;
    }

    public void setSumLunkInNum(BigDecimal sumLunkInNum) {
        this.sumLunkInNum = sumLunkInNum;
    }

    public BigDecimal getSumLunkOutNum() {
        return sumLunkOutNum;
    }

    public void setSumLunkOutNum(BigDecimal sumLunkOutNum) {
        this.sumLunkOutNum = sumLunkOutNum;
    }

    public BigDecimal getSumPipePcNum() {
        return sumPipePcNum;
    }

    public void setSumPipePcNum(BigDecimal sumPipePcNum) {
        this.sumPipePcNum = sumPipePcNum;
    }

    public BigDecimal getSumClampPcNum() {
        return sumClampPcNum;
    }

    public void setSumClampPcNum(BigDecimal sumClampPcNum) {
        this.sumClampPcNum = sumClampPcNum;
    }

    public BigDecimal getSumLunkPcNum() {
        return sumLunkPcNum;
    }

    public void setSumLunkPcNum(BigDecimal sumLunkPcNum) {
        this.sumLunkPcNum = sumLunkPcNum;
    }

    public String getOrgShortName() {
        return orgShortName;
    }

    public void setOrgShortName(String orgShortName) {
        this.orgShortName = orgShortName;
    }

    public BigDecimal getScaleZb() {
        return scaleZb;
    }

    public void setScaleZb(BigDecimal scaleZb) {
        this.scaleZb = scaleZb;
    }
}
